<?php
    /**
     * ReduxFramework Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {return;}

    // This is your option name where all the Redux data is stored.
    $opt_name = "rever_redux";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => false,
        // Show the sections below the admin menu item or not
        'menu_title'           => esc_html__( 'Theme Options', 'rever'),
        'page_title'           => esc_html__( 'Theme Options', 'rever'),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => true,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => true,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'red',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );
    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */

    // -> START Basic Fields
    $options_general=array(
        array(
            'id'       => 'logo',
            'type'     => 'media',
            'url'      => true,
            'title'    => esc_html__( 'Upload Your Logo', 'rever'),
            'subtitle' => esc_html__( 'If no Logo Uploaded then Your Site Name will display your Logo section, Edit this option Settings -> General Tab', 'rever'),
            'compiler' => 'true',
            'desc'     => '',
            'default'  => '',
        ),
        array(
            'id'       => 'favicon',
            'type'     => 'media',
            'url'      => true,
            'title'    => esc_html__( 'Upload Your Favicon', 'rever'),
            'subtitle' => esc_html__( 'Default Fav icon is located in our rever/assets/img/favicon.ico', 'rever'),
            'compiler' => 'true',
            'desc'     => '',
            'default'  => '',
        ),
        array(
            'id'       => 'header_search',
            'type'     => 'switch',
            'title'    => esc_html__( 'Enable Search on Header?', 'rever'),
            'subtitle' => esc_html__( 'Switching this will enable or disable search on the menu.', 'rever'),
            'default'  => 1,
        ),
        array(
            'id'       => 'header_social',
            'type'     => 'switch',
            'title'    => esc_html__( 'Enable Socials on Header?', 'rever'),
            'subtitle' => esc_html__( 'Switching this will enable or disable socials on the menu.', 'rever'),
            'default'  => 0,
        ),
        array(
            'id'       => 'header_socials_title',
            'type'     => 'text',
            'subtitle'    => esc_html__('Enter header socials title', 'rever'),
            'title'    => esc_html__('Follow us', 'rever'),
            'required' => array( 'header_social', '=', 1 ),
        ),
        array(
            'id'       => 'header_socials',
            'type'     => 'textarea',
            'subtitle'    => esc_html__('Enter social links. Example: facebook.com/themewaves. NOTE: Divide value sets with linebreak "Enter"', 'rever'),
            'title'    => esc_html__('Header Socials', 'rever'),
            'required' => array( 'header_social', '=', 1 ),
        ),
        array(
            'id'       => 'header_height',
            'type'     => 'text',
            'title'    => esc_html__( 'Header menu height (px)?', 'rever'),
            'default'  => '70',
        ),
        array(
            'id'       => 'scroll_menu',
            'type'     => 'switch',
            'title'    => esc_html__( 'Scroll Up Menu?', 'rever'),
            'subtitle'    => esc_html__( 'If you scroll up while scrolling down menu there has an Our menu is displayed and you can disable it', 'rever'),
            'default'  => 1,

        ),
        array(
            'id'=>'slider-section-start',
            'type' => 'section',
            'title' => esc_html__('Slider Options', 'rever'),
            'indent' => true // Indent all options below until the next 'section' option is set.
            ),
            array(
                'id'       => 'slider_height',
                'type'     => 'text',
                'title'    => esc_html__( 'Insert Slider Height?', 'rever'),
                'default'  => '560',
            ),
            array(
                'id'       => 'slider_height2',
                'type'     => 'text',
                'title'    => esc_html__( 'Full Slider Height (px)?', 'rever'),
                'default'  => '630',
            ),
            array(
                'id'       => 'slider_max_width',
                'type'     => 'text',
                'title'    => esc_html__( 'Insert Slider Content Max-Width?', 'rever'),
                'default'  => '600',
            ),
            array(
                'id'       => 'slider_auto',
                'type'     => 'switch',
                'title'    => esc_html__( 'Slider Auto Play?', 'rever'),
                'default'  => 0,
            ),
            array(
                'id'       => 'slider_delay',
                'type'     => 'text',
                'title'    => esc_html__( 'Slider Delay?', 'rever'),
                'default'  => '3000',
                'required' => array( 'slider_auto', '=', 1 ),
            ),
            array(
                'id'       => 'slider_full_click',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable Slide Click able', 'rever'),
                'subtitle' => esc_html__( 'If you disable it then you can click only Title. If you enabled then Entire Slide will link.', 'rever'),
                'default'  => 0,
            ),
            array(
                'id'       => 'slider_excerpt',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable Excerpt on Slider', 'rever'),
                'subtitle' => esc_html__( 'if you inserted Post Excerpt then it will be displayed.', 'rever'),
                'default'  => 0,
            ),
            array(
                'id'       => 'slider_meta',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable Slider Meta', 'rever'),
                'subtitle' => esc_html__( 'Author Name, Day, Comment', 'rever'),
                'default'  => 1,
            ),
            array(
                'id'       => 'slider_lead',
                'type'     => 'switch',
                'title'    => esc_html__( 'Increase the Slider and Content Font-Size', 'rever'),
                'subtitle' => esc_html__( 'Comfortable with the Slider 1 or Slider 2.', 'rever'),
                'default'  => 0,
            ),
        array(
            'id'=>'slider-section-end',
            'type' => 'section', 
            'indent' => false // Indent all options below until the next 'section' option is set.
        ),
    );
    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'General', 'rever'),
        'id'               => 'general',
        'customizer_width' => '400px',
        'icon'             => 'el el-home',
        'fields'           => $options_general
    ) );
    
    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Blog', 'rever'),
        'id'         => 'blog',
        'icon'       => 'el el-pencil',
        'fields'     => array(
            array(
                'id'=>'blog-section-start',
                'type' => 'section',
                'title' => esc_html__('General Blog Pages & Categories Options', 'rever'),
                'indent' => true // Indent all options below until the next 'section' option is set.
                ),
                array(
                    'id'       => 'blog_layout',
                    'type'     => 'image_select',
                    'title'    => esc_html__( 'Set Blog Layout', 'rever'),
                    'subtitle' => esc_html__( 'You can set the Normal, Large Media or Fullwidth. You can override it on Blog Single section', 'rever'),
                    'options'  => array(
                            'simple' => array(
                                'alt' => esc_html__('Simple', 'rever'),
                                'title' => esc_html__('Simple', 'rever'),
                                'img' => REVER_DIR . 'assets/img/01.png'
                            ),
                            'grid' => array(
                                'alt' => esc_html__('Grid', 'rever'),
                                'title' => esc_html__('Grid', 'rever'),
                                'img' => REVER_DIR . 'assets/img/02.png'
                            ),
                            'list' => array(
                                'alt' => esc_html__('List', 'rever'),
                                'title' => esc_html__('List', 'rever'),
                                'img' => REVER_DIR . 'assets/img/03.png'
                            ),
                            'list2' => array(
                                'alt' => esc_html__('List right thumb', 'rever'),
                                'title' => esc_html__('List right thumb', 'rever'),
                                'img' => REVER_DIR . 'assets/img/04.png'
                            ),
                            'square' => array(
                                'alt' => esc_html__('Featured', 'rever'),
                                'title' => esc_html__('Featured', 'rever'),
                                'img' => REVER_DIR . 'assets/img/05.png'
                            )
                        ),
                    'default'  => 'simple',
                ),
                array(
                    'id'       => 'blog_sidebar',
                    'type'     => 'select',
                    'title'    => esc_html__( 'Blog sidebar', 'rever' ),
                    'subtitle' => esc_html__( 'Have a Sidebar ?', 'rever' ),
                    'options'  => array(
                        'true' => 'True',
                        'false' => 'False',
                    ),
                    'default'  => 'true'
                ),
                array(
                    'id'       => 'blog_excerpt',
                    'type'     => 'text',
                    'title'    => esc_html__( 'Blog excerpt?', 'rever' ),
                    'subtitle' => esc_html__( 'Excerpt word count', 'rever' ),
                    'default'  => ''
                ),
                array(
                    'id'       => 'blog_pagination',
                    'type'     => 'select',
                    'title'    => esc_html__( 'Blog pagination', 'rever' ),
                    'subtitle' => esc_html__( 'Pagination type ?', 'rever' ),
                    'options'  => array(
                        'simple' => 'Simple',
                        'number' => 'Numbered',
                        'infinite' => 'Infinite',
                        'none' => 'None',
                    ),
                    'default'  => 'simple'
                ),
                array(
                    'id'       => 'gif_auto_blog',
                    'type'     => 'switch',
                    'title'    => esc_html__( 'GIF auto play on Row Builder?', 'rever'),
                    'subtitle'     => esc_html__( 'Gif can autoplay or Play Button on Homepage.', 'rever'),
                    'default'  => 1,
                ),
            array(
                'id'=>'blog-section-end',
                'type' => 'section', 
                'indent' => false // Indent all options below until the next 'section' option is set.
            ),
            array(
                'id'=>'blog-single-start',
                'type' => 'section',
                'title' => esc_html__('Blog Single Options', 'rever'),
                'indent' => true // Indent all options below until the next 'section' option is set.
                ),
                array(
                'id'       => 'single_layout',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Set Blog Single Layout', 'rever'),
                'subtitle' => esc_html__( 'You can set the Normal, Large Media or Fullwidth. You can override it on Blog Single section', 'rever'),
                'options'  => array(
                        'right-sidebar' => array(
                            'alt' => esc_html__('Right Sidebar', 'rever'),
                            'title' => esc_html__('Right Sidebar', 'rever'),
                            'img' => REVER_DIR . 'assets/img/single_rightsidebar.png'
                        ),
                        'left-sidebar' => array(
                            'alt' => esc_html__('Left Sidebar', 'rever'),
                            'title' => esc_html__('Left Sidebar', 'rever'),
                            'img' => REVER_DIR . 'assets/img/single_leftsidebar.png'
                        ),
                        'fullwidth-content' => array(
                            'alt' => esc_html__('Fullwidth Content', 'rever'),
                            'title' => esc_html__('Fullwidth Content', 'rever'),
                            'img' => REVER_DIR . 'assets/img/single_fullwidth.png'
                        ),
                        'narrow-content' => array(
                            'alt' => esc_html__('Narrow Content', 'rever'),
                            'title' => esc_html__('Narrow Content', 'rever'),
                            'img' => REVER_DIR . 'assets/img/single_narrow.png'
                        )
                    ),
                    'default'  => 'right-sidebar',
                    ),
                    array(
                        'id'       => 'single_media',
                        'type'     => 'image_select',
                        'title'    => esc_html__( 'Single media layout', 'rever' ),
                        'subtitle' => esc_html__( 'You can override it on Blog Single section', 'rever' ),
                        'options'  => array(
                            'small' => array(
                                'alt' => esc_html__('Featured area small', 'rever'),
                                'title' => esc_html__('Featured area small', 'rever'),
                                'img' => REVER_DIR . 'assets/img/media_small.png'
                            ),
                            'large' => array(
                                'alt' => esc_html__('Featured area large', 'rever'),
                                'title' => esc_html__('Featured area large', 'rever'),
                                'img' => REVER_DIR . 'assets/img/media_large.png'
                            ),
                            'large2' => array(
                                'alt' => esc_html__('Featured area large 2', 'rever'),
                                'title' => esc_html__('Featured area large 2', 'rever'),
                                'img' => REVER_DIR . 'assets/img/media_large2.png'
                            ),
                            'fullwidth' => array(
                                'alt' => esc_html__('Featured area fullwidth', 'rever'),
                                'title' => esc_html__('Featured area fullwidth', 'rever'),
                                'img' => REVER_DIR . 'assets/img/media_fullwidth.png'
                            ),
                            'none' => array(
                                'alt' => esc_html__('Featured area none', 'rever'),
                                'title' => esc_html__('Featured area None', 'rever'),
                                'img' => REVER_DIR . 'assets/img/slider_empty.png'
                            )
                        ),
                        'default'  => 'small'
                    ),
                    array(
                        'id'       => 'sidebar_affix',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Sidebar Affix', 'rever'),
                        'subtitle' => esc_html__( 'If you set this on Sidebar areas will be affixed.', 'rever'),
                        'default'  => 0,
                    ),
                    array(
                        'id'       => 'gif_auto_single',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'GIF auto play on blog single?', 'rever'),
                        'subtitle'     => esc_html__( 'In the Blog Single it can be autplay or Play button', 'rever'),
                        'default'  => 0,
                    ),
                    array(
                        'id'       => 'single_share',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Post share on single?', 'rever'),
                        'subtitle'     => esc_html__( 'Social shares visible or not on Single Post area', 'rever'),
                        'default'  => 1,
                    ),
                    array(
                        'id'       => 'single_pagination',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Next, Prev post on single?', 'rever'),
                        'default'  => 0,
                    ),
                    array(
                        'id'       => 'single_cats',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Post cats on single?', 'rever'),
                        'subtitle'     => esc_html__( 'Post categories', 'rever'),
                        'default'  => 1,
                    ),
                    array(
                        'id'       => 'single_meta',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Post meta on single?', 'rever'),
                        'subtitle'     => esc_html__( 'Post date and author', 'rever'),
                        'default'  => 1,
                    ),
                    array(
                        'id'       => 'single_tags',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Post tags on single?', 'rever'),
                        'subtitle'     => esc_html__( 'Tag on single', 'rever'),
                        'default'  => 1,
                    ),
                    array(
                        'id'       => 'single_author',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Post author on single?', 'rever'),
                        'subtitle'     => esc_html__( 'About author on single', 'rever'),
                        'default'  => 1,
                    ),
                    array(
                        'id'       => 'related_posts',
                        'type'     => 'select',
                        'title'    => esc_html__( 'Related Posts on Single ?', 'rever' ),
                        'options'  => array(
                            '' => 'None',
                            '2' => '2',
                            '4' => '4',
                            '6' => '6',
                        ),
                        'default'  => '4'
                    ),
                array(
                    'id'=>'blog-single-end',
                    'type' => 'section', 
                    'indent' => false // Indent all options below until the next 'section' option is set.
                ),
        )
    ) );
    
    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Color', 'rever'),
        'id'         => 'color',
        'icon'       => 'el el-eye-open',
        'fields'     => array(
            array(
                'id'       => 'primary_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Primary Color?', 'rever'),
                'subtitle' => esc_html__('This is your main Primary Color.','rever'),   
                'default'  => '#1de118',
            ),
            array(
                'id'=>'body-section-start',
                'type' => 'section',
                'title' => esc_html__('General Color', 'rever'),
                'indent' => true // Indent all options below until the next 'section' option is set.
                ),
            array(
                'id'       => 'body_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Body Color?', 'rever'),
                'default'  => '#444444',
            ),
            array(         
                'id'       => 'body_bg',
                'type'     => 'background',
                'title'    => esc_html__('Body Background', 'rever'),
                'subtitle' => esc_html__('This will works whole background area. If you chosen the Boxed Layout then it will work outside of Container area. It will not work if you have chosen Full Layout', 'rever'),
                'default'  => array(
                    'background-color' => '#f5f5f5',
                )
            ),
            array(         
                'id'       => 'ex_sidebar_bg',
                'type'     => 'color',
                'title'    => esc_html__('Extended Sidebar Menu Background', 'rever'),
                'subtitle' => esc_html__('Extended Sidebar Menu Background Color', 'rever'),
                'default'  => '#151515',
                'output'   => array(
                    'background-color' => '.tw-mobile-menu'
                )
            ),
            array(
                'id'       => 'heading_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Heading Title Color (H1-H6)?', 'rever'),
                'default'  => '#151515',
            ),
            array(
                'id'       => 'post_metacolor',
                'type'     => 'color',
                'title'    => esc_html__( 'Blog Meta Color?', 'rever'),
                'subtitle' => esc_html__( 'Post Share & Post Comment and Date?', 'rever'),
                'default'  => '#999',
            ),
            array(
                'id'       => 'link_color',
                'type'     => 'link_color',
                'title'    => esc_html__( 'Link Color?', 'rever'),
                'subtitle' => '',
                'default'  => array(
                    'regular' => '#808080',
                    'hover'   => '#999999',
                    'active'  => false,
                )
            ),
            array(
                'id'       => 'border_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Border Color?', 'rever'),
                'subtitle' => 'table, image description, post comment, widget, footer etc... ',
                'default'  => '#e6e6e6',
            ),
            array(
                'id'       => 'input_bg',
                'type'     => 'color',
                'title'    => esc_html__( 'Input Background Color?', 'rever'),
                'subtitle' => 'and tags, author box, next prev posts, comment form etc... ',
                'default'  => '#f5f5f5',
            ),
            
            
            array(
                'id'=>'body-section-end',
                'type' => 'section', 
                'indent' => false // Indent all options below until the next 'section' option is set.
            ),
            
            array(
                'id'=>'post-section-start',
                'type' => 'section',
                'title' => esc_html__('Post Area Colors', 'rever'),                           
                'indent' => true // Indent all options below until the next 'section' option is set.
            ),
            array(
                'id'       => 'post_bg_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Post Background Color?', 'rever'),
                'subtitle' => '',
                'default'  => '#fff',
            ),
            array(
                'id'       => 'post_link',
                'type'     => 'link_color',
                'title'    => esc_html__( 'Post Link Color?', 'rever'),
                'subtitle' => '',
                'default'  => array(
                    'regular' => '#151515',
                    'hover'   => '#999',
                    'active'  => false,
                )
            ),
            array(
                'id'=>'post-section-end',
                'type' => 'section', 
                'indent' => false // Indent all options below until the next 'section' option is set.
            ),
            
            array(
                'id'=>'header-section-start',
                'type' => 'section',
                'title' => esc_html__('Header Area Colors', 'rever'),                           
                'indent' => true // Indent all options below until the next 'section' option is set.
                ),
            array(
                'id'       => 'header_bgcolor',
                'type'     => 'color',
                'title'    => esc_html__( 'Header BG Color?', 'rever'),
                'subtitle' => '',
                'default'  => '#151515',
            ),
            array(
                'id'       => 'menu_color',
                'type'     => 'color',
                'title'    => esc_html__('Header area text color?', 'rever'),
                'subtitle' => esc_html__('Note: menu,logo and search icon?', 'rever'),
                'default'  => '#cccccc',
            ),
            array(
                'id'       => 'menu_hover',
                'type'     => 'color',
                'title'    => esc_html__('Menu hover color?', 'rever'),
                'subtitle' => esc_html__('If you want to disable it then set the same color for Header area text color.', 'rever'),
                'default'  => '#ffffff',
            ),
            array(
                'id'       => 'submenu_bg',
                'type'     => 'color',
                'title'    => esc_html__('SubMenu BG color?', 'rever'),
                'subtitle' => '',
                'default'  => '#151515',
            ),
            array(
                'id'       => 'submenu_hover_bg',
                'type'     => 'color',
                'title'    => esc_html__('SubMenu Hover BG color?', 'rever'),
                'subtitle' => '',
                'default'  => '#262626',
            ),
            array(
                'id'       => 'submenu_color',
                'type'     => 'color',
                'title'    => esc_html__('SubMenu Text color?', 'rever'),
                'subtitle' => '',
                'default'  => '#cccccc',
            ),
            array(
                'id'       => 'submenu_hover_color',
                'type'     => 'color',
                'title'    => esc_html__('SubMenu Hover Text color?', 'rever'),
                'subtitle' => '',
                'default'  => '#fff',
            ),
           
            array(
                'id'=>'header-section-end',
                'type' => 'section', 
                'indent' => false // Indent all options below until the next 'section' option is set.
            ),
            
            array(
                'id'=>'footer-section-start',
                'type' => 'section',
                'title' => esc_html__('Footer Area Colors', 'rever'),                           
                'indent' => true // Indent all options below until the next 'section' option is set.
            ),
            array(
                'id'       => 'footer_text_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Footer Text Color?', 'rever'),
                'subtitle' => '',
                'default'  => '#999',
            ),
            array(
                'id'       => 'footer_link_color',
                'type'     => 'link_color',
                'title'    => esc_html__( 'Link Color?', 'rever'),
                'subtitle' => '',
                'default'  => array(
                    'regular' => '#999',
                    'hover'   => '#151515',
                    'active'  => false,
                )
            ),
            array(
                'id'=>'footer-section-end',
                'type' => 'section', 
                'indent' => false // Indent all options below until the next 'section' option is set.
            ),
        )
    ) );

    // -> START Typography
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Typography', 'rever'),
        'id'     => 'typography',
        'icon'   => 'el el-fontsize',
        'fields' => array(
            array(
                'id'       => 'body_font',
                'type'     => 'typography',
                'title'    => esc_html__( 'Body Font', 'rever'),
                'subtitle' => esc_html__( 'Site whole Text on Body area.', 'rever'),
                'google'   => true,
                'font-style'  => true,
                'font-weight'  => true,
                'text-align'  => false,
                'color'  => false,
                'all_styles'  => true,
                'font-backup'  => true,
                'line-height'  => false,
                'default'  => array(
                    'font-size'   => '16px',
                    'font-family' => 'Droid Sans',
                    'font-weight' => '400',
                    'font-backup'  => 'Arial, Helvetica, sans-serif',
                ),
            ),
            array(
                'id'          => 'menu_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'Main Menu Font', 'rever'),
                'google'   => true,
                'font-style'  => true,
                'font-weight'  => true,
                'text-align'  => false,
                'text-transform'  => true,
                'color'  => false,
                'font-size'  => true,
                'line-height'  => false,
                'all_styles'  => false,
                'default'  => array(
                    'font-family' => 'Poppins',
                    'font-size'   => '10px',
                    'font-style'  => '',
                    'text-transform'  => 'uppercase',
                    'font-weight' => '700'
                ),
            ),
            array(
                'id'          => 'submenu_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'SubMenu font size', 'rever'),
                'google'   => true,
                'font-family'  => true,
                'font-style'  => false,
                'font-weight'  => true,
                'text-transform'  => true,
                'text-align'  => false,
                'color'  => false,
                'font-size'  => true,
                'line-height'  => false,
                'all_styles'  => false,
                'default'  => array(
                    'font-family'  => 'Poppins',
                    'font-size'  => '10px',
                    'font-weight'  => '700',
                    'text-transform'  => 'uppercase',
                ),
            ),
            array(
                'id'          => 'meta_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'Post Meta Font', 'rever'),
                'subtitle'    => esc_html__( 'Date time, comment count and share count.', 'rever'),
                'google'   => true,
                'font-style'  => true,
                'font-weight'  => true,
                'text-align'  => false,
                'color'  => false,
                'text-transform'  => true,
                'font-size'  => true,
                'line-height'  => false,
                'all_styles'  => false,
                'default'  => array(
                    'font-family' => 'Droid Sans',
                    'font-weight' => '400',
                    'font-size'  => '12px',
                    'text-transform'  => 'none',
                ),
            ),
            array(
                'id'          => 'heading_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'Heading Title Font', 'rever'),
                'subtitle'    => esc_html__( 'H1-H6 and any Post Titles.', 'rever'),
                'google'   => true,
                'font-style'  => true,
                'font-weight'  => true,
                'text-align'  => false,
                'text-transform'  => true,
                'color'  => false,
                'font-size'  => false,
                'line-height'  => false,
                'all_styles'  => true,
                'default'  => array(
                    'font-family' => 'Poppins',
                    'font-style'  => '',
                    'text-transform'  => '',
                    'font-weight' => '700'
                ),
            ),
            array(
                'title' => esc_html__('Heading Title Tags Size', 'rever'),
                'id' => 'tab_typography_sub_tag_start',
                'type' => 'section',
                'indent' => true,
            ),
            
            array(
                'id'          => 'h1_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'H1', 'rever'),
                'google'   => false,
                'font-family'  => false,
                'font-style'  => false,
                'font-weight'  => false,
                'text-align'  => false,
                'color'  => false,
                'font-size'  => true,
                'line-height'  => false,
                'all_styles'  => false,
                'default'  => array(
                    'font-size'  => '36px',
                ),
            ),
            array(
                'id'          => 'h2_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'H2', 'rever'),
                'google'   => false,
                'font-family'  => false,
                'font-style'  => false,
                'font-weight'  => false,
                'text-align'  => false,
                'color'  => false,
                'font-size'  => true,
                'line-height'  => false,
                'all_styles'  => false,
                'default'  => array(
                    'font-size'  => '30px',
                ),
            ),
            array(
                'id'          => 'h3_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'H3', 'rever'),
                'google'   => false,
                'font-family'  => false,
                'font-style'  => false,
                'font-weight'  => false,
                'text-align'  => false,
                'color'  => false,
                'font-size'  => true,
                'line-height'  => false,
                'all_styles'  => false,
                'default'  => array(
                    'font-size'  => '24px',
                ),
            ),
            array(
                'id'          => 'h4_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'H4', 'rever'),
                'google'   => false,
                'font-family'  => false,
                'font-style'  => false,
                'font-weight'  => false,
                'text-align'  => false,
                'color'  => false,
                'font-size'  => true,
                'line-height'  => false,
                'all_styles'  => false,
                'default'  => array(
                    'font-size'  => '20px',
                ),
            ),
            array(
                'id'          => 'h5_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'H5', 'rever'),
                'google'   => false,
                'font-family'  => false,
                'font-style'  => false,
                'font-weight'  => false,
                'text-align'  => false,
                'color'  => false,
                'font-size'  => true,
                'line-height'  => false,
                'all_styles'  => false,
                'default'  => array(
                    'font-size'  => '16px',
                ),
            ),
            array(
                'id'          => 'h6_font',
                'type'        => 'typography',
                'title'       => esc_html__( 'H6', 'rever'),
                'google'   => false,
                'font-family'  => false,
                'font-style'  => false,
                'font-weight'  => false,
                'text-align'  => false,
                'color'  => false,
                'font-size'  => true,
                'line-height'  => false,
                'all_styles'  => false,
                'default'  => array(
                    'font-size'  => '14px',
                ),
            ),
            array(
                'id' => 'tab_typography_sub_tag_end',
                'type' => 'section',
                'indent' => false,
            ),
        )
    ) );
    
    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Footer', 'rever'),
        'id'         => 'footer',
        'icon'       => 'el el-photo',
        'fields'     => array(
            array(
                'id'       => 'footer_text',
                'type'     => 'textarea',
                'title'    => esc_html__('Footer Left Text', 'rever'),
                'subtitle' => esc_html__('You can use HTML tags on this area', 'rever'),
                'default'  => wp_kses_post(sprintf(__( '&copy; 2017 <a href="%s">Rever Magazine Theme.</a> All rights reserved.', 'rever'), 'https://themeforest.net/user/themewaves')),
            ),
            array(
                'id'       => 'footer_socials',
                'type'     => 'textarea',
                'subtitle'    => esc_html__('Enter social links. Example: facebook.com/themewaves. NOTE: Divide value sets with linebreak "Enter":', 'rever'),
                'title'    => esc_html__('Footer Socials', 'rever'),
                'default'  => '',
            ),
            array(
                'id'       => 'footer_socials_color',
                'type'     => 'select',
                'title'    => esc_html__( 'Footer Social Style', 'rever' ),
                'subtitle' => esc_html__( 'You can change the colors on Color Options Tab', 'rever' ),
                'options'  => array(
                    '' => 'Primary color',
                    'social-light' => 'Light',
                    'social-dark' => 'Dark'
                ),
                'default'  => 'social-light'
            ),
        )
    ) );
    
    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Translation', 'rever'),
        'id'         => 'translation',
        'icon'       => 'el el-globe',
        'fields'     => array(
            array(
                'id'       => 'readmore',
                'type'     => 'text',
                'title'    => esc_html__( 'Read more text on Slider', 'rever'),
                'subtitle' => '',
                'default'  => esc_html__( 'Read more', 'rever'),
            ),
            array(
                'id'       => 'text_older',
                'type'     => 'text',
                'title'    => esc_html__( 'Older posts text on Pagination', 'rever'),
                'subtitle' => '',
                'default'  => esc_html__( 'Older Posts', 'rever'),
            ),
            array(
                'id'       => 'text_newer',
                'type'     => 'text',
                'title'    => esc_html__( 'Newer posts text on Pagination', 'rever'),
                'subtitle' => '',
                'default'  => esc_html__( 'Newer Posts', 'rever'),
            ),
            array(
                'id'       => 'text_prev',
                'type'     => 'text',
                'title'    => esc_html__( 'Prev posts text on Numbered Pagination', 'rever'),
                'subtitle' => '',
                'default'  => esc_html__( 'Prev', 'rever'),
            ),
            array(
                'id'       => 'text_next',
                'type'     => 'text',
                'title'    => esc_html__( 'Next posts text on Numbered Pagination', 'rever'),
                'subtitle' => '',
                'default'  => esc_html__( 'Next', 'rever'),
            ),
            array(
                'id'       => 'text_loadmore',
                'type'     => 'text',
                'title'    => esc_html__( 'Load More on Infinite Pagination', 'rever'),
                'subtitle' => '',
                'default'  => esc_html__( 'Load More', 'rever'),
            ),
            array(
                'id'       => 'text_search',
                'type'     => 'text',
                'title'    => esc_html__( 'Search placeholder', 'rever'),
                'subtitle' => '',
                'default'  => esc_html__( 'Search...', 'rever'),
            ),
        )
    ) );
    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Custom CSS', 'rever'),
        'id'         => 'custom_css_tab',
        'icon'       => 'el el-css',
        'fields'     => array(
            array(
                'id'       => 'custom_css',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Custom CSS', 'rever'),
                'subtitle' => esc_html__('Paste your CSS code here.', 'rever'),
                'mode'     => 'css',
                'theme'    => 'chrome',
            )
        )
    ) );
    Redux::setSection( $opt_name, array(
        'title' => esc_html__( 'Ads management', 'rever' ),
        'id'    => 'adsense',
        'desc'  => '',
        'icon'  => 'el el-screenshot',
        'fields' => array(
            array(
                'id'       => 'ads-single',
                'type'     => 'editor',
                'title'    => esc_html__('Single Content Above', 'rever'), 
                'subtitle' => esc_html__('It will be displayed above the Single Content, You can insert anything Ad or custom image or text anything.', 'rever'),
                'desc'    => '', 
                'default'  => '',
                'args'   => array(
                    'teeny'            => true,
                    'textarea_rows'    => 5
                )
            ),
            array(
                'id'       => 'ads-blog',
                'type'     => 'editor',
                'title'    => esc_html__('Blog Page Above', 'rever'), 
                'subtitle' => esc_html__('It will be displayed above the Blog Page, You can insert anything Ad or custom image or text anything.', 'rever'),
                'desc'    => '', 
                'default'  => '',
                'args'   => array(
                    'teeny'            => true,
                    'textarea_rows'    => 5
                )
            ),
        )
    ));
