<?php

$theme_obj = wp_get_theme();
$theme_name = $theme_obj->get('Name');
$theme_version = $theme_obj->get('Version');

define('REVER_THEMENAME', $theme_name);
define('REVER_THEMEVERSION', $theme_version);
define('REVER_META', 'themewaves_' . strtolower(str_replace(' ', '_', REVER_THEMENAME)) . '_options');
define('REVER_PATH', trailingslashit(get_template_directory()));
define('REVER_DIR', trailingslashit(get_template_directory_uri()));
define('REVER_STYLESHEET_DIR', trailingslashit(get_stylesheet_directory_uri()));

if (is_admin()) {
    require( REVER_PATH . 'framework/tgm-plugins.php');
    add_action('admin_enqueue_scripts', 'rever_admin_scripts');

    function rever_admin_scripts() {
        $pid = isset($post->ID) ? $post->ID : 0;
        wp_localize_script('jquery', 'rever_script_data', array(
            'home_uri' => esc_url(home_url('/')),
            'post_id' => esc_attr($pid),
            'nonce' => esc_attr(wp_create_nonce('themewaves-ajax')),
            'image_ids' => esc_attr(rever_metabox('gallery_image_ids')),
            'label_create' => esc_html__("Create Featured Gallery", 'rever'),
            'label_edit' => esc_html__("Edit Featured Gallery", 'rever'),
            'label_save' => esc_html__("Save Featured Gallery", 'rever'),
            'label_saving' => esc_html__("Saving...", 'rever'),
        ));
        
        wp_register_script('rever-admin-js', REVER_DIR . 'framework/js/waves-admin.js');
        wp_enqueue_script('rever-admin-js');
        
        wp_register_style('rever-admin-css', REVER_DIR . 'framework/css/waves-admin.css', false, '1.00', 'screen');
        wp_enqueue_style('rever-admin-css');
    }

}

require_once (REVER_PATH . "framework/waves_options/waves-options.php");
require_once (REVER_PATH . "framework/theme_functions.php");
require_once (REVER_PATH . "framework/blog_functions.php");
require_once (REVER_PATH . "framework/waves_widget/widget_socials.php");
require_once (REVER_PATH . "framework/waves_widget/widget_post.php");
require_once (REVER_PATH . "framework/waves_widget/widget_instagram.php");
require_once (REVER_PATH . "framework/theme_css.php");



/* ================================================================================== */
/*      Theme Supports
  /* ================================================================================== */

add_action('after_setup_theme', 'rever_setup');
if (!function_exists('rever_setup')) {

    function rever_setup() {
        add_theme_support('post-thumbnails');
        add_theme_support('post-formats', array('gallery', 'video', 'audio'));
        add_theme_support('title-tag');
        add_theme_support('automatic-feed-links');
        load_theme_textdomain('rever', REVER_PATH . 'languages/');
        register_nav_menus(array('main' => esc_html__('Main Menu', 'rever'), 'footer' => esc_html__('Footer Menu', 'rever')));

        add_image_size('rever_single_post', 770);
        add_image_size('rever_blog_large', 1170, 660, true);
        add_image_size('rever_blog_thumb', 770, 360, true);
        add_image_size('rever_grid_thumb', 400, 280, true);
        add_image_size('rever_square_thumb', 400, 650, true);
        add_image_size('rever_list_thumb', 570, 360, true);
        add_image_size('rever_large_list', 700, 440, true);
        add_image_size('rever_slider_thumb', 770, 500, true);
        add_image_size('rever_carousel_widget', 370, 410, true);
    }

}
if (!isset($content_width)) {
    $content_width = 1170;
}



/* ================================================================================== */
/*      Enqueue Scripts
  /* ================================================================================== */

add_action('wp_enqueue_scripts', 'rever_scripts');

function rever_scripts() {
    wp_enqueue_style('bootstrap', REVER_DIR . 'assets/css/bootstrap.min.css');
    wp_enqueue_style('ionicons', REVER_DIR . 'assets/css/ionicons.min.css');
    wp_enqueue_style('rever-style', REVER_DIR . 'style.css');
    wp_enqueue_style('rever-responsive', REVER_DIR . 'assets/css/responsive.css');
    wp_enqueue_style('magnific-popup', REVER_DIR . 'assets/css/magnific-popup.css');
    wp_add_inline_style('rever-responsive', rever_option_styles());
    
    wp_enqueue_script('rever-functions', REVER_DIR . 'assets/js/functions.js', false, false, false);
    wp_enqueue_script('superfish', REVER_DIR . 'assets/js/superfish.min.js', array('jquery'), false, true);
    wp_enqueue_script('fluidvids', REVER_DIR . 'assets/js/fluidvids.min.js', array('jquery'), false, true);
    wp_enqueue_script('libgif', REVER_DIR . 'assets/js/libgif.js', array('jquery'), false, true);
    wp_enqueue_script('rubbable', REVER_DIR . 'assets/js/rubbable.js', array('jquery'), false, true);
    if (is_single() && comments_open()) {
        wp_enqueue_script('comment-reply');
    }
    wp_enqueue_script('html5', REVER_DIR . 'assets/js/html5.js', array(), '3.6.0');
    wp_script_add_data('html5', 'conditional', 'lt IE 9');
    wp_register_script('owl-carousel', REVER_DIR . 'assets/js/owl.carousel.min.js');
    wp_enqueue_script('magnific-popup', REVER_DIR . 'assets/js/jquery.magnific-popup.min.js');

    if (rever_option('sidebar_affix')) {
        wp_enqueue_script('theiastickysidebar', REVER_DIR . 'assets/js/theiaStickySidebar.js', false, false, true);
    }
    wp_enqueue_script('rever-script', REVER_DIR . 'assets/js/waves-script.js');
    wp_localize_script('jquery', 'rever_script_data', array(
        'gif_auto' => is_single() ? rever_option('gif_auto_single', '0') : rever_option('gif_auto_blog', '1'),
        'slider_auto' => rever_option('slider_auto', '0')?true:false,
        'slider_delay' => rever_option('slider_delay', '3000'),
    ));
}

/* ================================================================================== */
/*      Register Widget Sidebar
  /* ================================================================================== */

if (!function_exists('rever_widgets_init')) {

    function rever_widgets_init() {
        register_sidebar(array(
            'name' => esc_html__('Default sidebar', 'rever'),
            'id' => 'default-sidebar',
            'before_widget' => '<aside class="widget %2$s" id="%1$s"><div class="widget-item">',
            'after_widget' => '</div></aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
        register_sidebar(array(
            'name' => esc_html__('Mobile sidebar', 'rever'),
            'id' => 'mobile-sidebar',
            'before_widget' => '<aside class="widget %2$s" id="%1$s"><div class="widget-item">',
            'after_widget' => '</div></aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));        
    }

}
add_action('widgets_init', 'rever_widgets_init');



/* ================================================================================== */
/*      ThemeWaves Search Form Customize
  /* ================================================================================== */

function rever_searchmenu() {
    $form = '<form method="get" class="searchform on-menu" action="' . esc_url(home_url('/')) . '" >';
    $form .= '<div class="input"><input type="text" value="' . get_search_query() . '" name="s" placeholder="' . esc_html__('Search', 'rever') . '" /><i class="ion-search"></i></div>';
    $form .= '</form>';
    return $form;
}

function rever_searchform() {

    $form = '<form method="get" class="searchform" action="' . esc_url(home_url('/')) . '" >
    <div class="input">
    <input type="text" value="' . get_search_query() . '" name="s" placeholder="' . rever_option('text_search', esc_html__('Search...', 'rever')) . '" />
        <button type="submit" class="button-search"><i class="ion-search"></i></button>
    </div>
    </form>';

    return $form;
}
add_filter('get_search_form', 'rever_searchform');

/* Exclude Category */

function rever_exclude_widget_cats($args) {
    $categories = get_categories();
    $exclude = array();
    foreach ($categories as $category) {
        $options = get_option("taxonomy_" . $category->cat_ID);
        if (isset($options['featured']) && $options['featured']) {
            $exclude[] = $category->cat_ID;
        }
    }
    $args["exclude"] = $exclude;
    return $args;
}

add_filter("widget_categories_args", "rever_exclude_widget_cats");

/* WordPress Edit Gallery */
add_filter('use_default_gallery_style', '__return_false');
add_filter('wp_get_attachment_link', 'rever_pretty_gallery', 10, 5);

function rever_pretty_gallery($content, $id, $size = 'large', $permalink) {
    if (!$permalink)
        $content = preg_replace("/<a/", "<a rel=\"prettyPhoto[gallery]\"", $content, 1);
    $content = preg_replace("/<\/a/", "<div class=\"image-overlay\"></div></a", $content, 1);
    return $content;
}

function rever_body_class($classes) {
    global $rever_options;

    if (is_single()) {
        $rever_options = rever_metaboxes();
        if (empty($rever_options['single_media'])) {
            $rever_options['single_media'] = rever_option('single_media', 'small');
        }
        if(empty($rever_options['single_layout'])){
            $rever_options['single_layout'] = rever_option('single_layout', 'right-sidebar');
        }
    }
    
    if( rever_option('scroll_menu') ){
        $classes[] = 'scroll-menu';
    }

    return $classes;
}
add_filter('body_class', 'rever_body_class');
add_filter('jpeg_quality', function() {
    return 100;
});
